<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Auth.php
 *
 * This is administrator authorization file
 *
 * @category	controllers
 * @package		LP cms
 * @link		https://lpcms.net
 * @copyright	2017
 * @license 	MIT License (https://en.wikipedia.org/wiki/MIT_License)
 * @version 	0.1 Beta
 */

/**
 * Auth
 * 
 * This is Authorization class
 * 
 * @author 		Developers of lpcms.net <dev@lpcms.net>
 * @see 		/auth/
 * @version 	0.1 Beta
 */
class Auth extends CI_Controller {
	
	/**
	 * _login_rules
	 * 
	 * @var array
	 */
	private $_login_rules = array(
		'field' => 'valueLogin',
        'name' 	=> 'Login',
        'rules' => 'trim|required|min_length[5]|max_length[16]|alpha'
	);

	/**
	 * _password_rules
	 * 
	 * @var array
	 */
	private $_password_rules = array(
		'field' => 'valuePassword',
        'name' 	=> 'Password',
        'rules' => 'trim|required|min_length[6]|max_length[16]|alpha_numeric'
	);

	/**
	 * index
	 * 
	 * This function is Index Page of controller
	 *
	 * @access public
	 * @param string $error_message
	 */
	public function index($error_message = '') {

		/**
		 * Check authorization
		 */
		if ($this->form_validation->run() == FALSE) {
			$this -> ischecks -> checkAuthorization();
		}
		
		/**
		 * Set GET parameters for LOGIN and PASSWORD 
		 */
		if ($this -> input -> get('auth') !== NULL and $this -> input -> get('auth') == 'demo') {
			$get_login = 'admin';
			$get_password = 'adminpass';
		} else {
			$get_login = '';
			$get_password = '';
		}

		/**
		 * Set parameters for our template
		 */
		$data_auth = array(
			'title'				=> 'Authorization',
			'pub_admin_css_path'=> $this -> configloader -> _config['paths']['pub_admin_css'],
			'pub_admin_js'		=> $this -> configloader -> _config['paths']['pub_admin_js'],
			'file_style'		=> $this -> configloader -> _config['admin_style']['auth'],
			'login_value'		=> set_value('valueLogin', $get_login),
			'password_value'	=> set_value('valuePassword', $get_password),
			'email_value'		=> set_value('valueEmail', ''),
			'remember_value'	=> set_value('valueRemember', '') ? ' checked="checked"' : '',
			'robot_value'		=> set_value('valueRobot', '') ? ' checked="checked"' : '',
			'errors'			=> $error_message,
			// 'pub_user_js'	 	=> $this -> configloader -> _config['paths']['pub_user_js'],
			// 'js_file_path' 	 	=> $this -> configloader -> _config['user_js_file']['category_js'],
			'year'				=> $this -> configloader -> _config['numbers']['year_now'],

		);

		/**
		 * Parse our templates
		 */
		$template_auth = $this -> configloader -> _config['templates_admin']['auth'];

		/**
		 * Parse our template
		 */
		$this -> parser -> parse($template_auth, $data_auth);
	}

	/**
	 * check_form
	 * 
	 * This function check a user form
	 * 
	 * @access public
	 */
	public function check_form() {

		/**
		 * Login validation
		 */
		$this -> form_validation -> set_rules($this -> _login_rules['field'], $this -> _login_rules['name'], $this -> _login_rules['rules']);
		
		/**
		 * Password validation
		 */
		$this -> form_validation -> set_rules($this -> _password_rules['field'], $this -> _password_rules['name'], $this -> _password_rules['rules']);
		
		/**
		 * Set container for error block
		 */
		$this -> form_validation -> set_error_delimiters('<div class="bg-danger">', '</div>');
		
		/**
		 * If form not form valid then show error or set cookies
		 */
		if ($this -> form_validation -> run() == FALSE) {
			$this -> index(validation_errors());
		} else {
			/**
			 * Set variables from POST data
			 */
			$login_post = $this -> input -> post('valueLogin');
			$password_post = md5(md5($this -> input -> post('valuePassword')));
			$robots_post = $this -> input -> post('valueEmail');
			$robots_checkbox = $this -> input -> post('valueRobot');
			$admin_data_array = $this -> auth_model -> getAdminData($login_post);

			/**
			 * Set auth or show error
			 */
			if ((isset($robots_post) and !empty($robots_post)) or (!isset($robots_checkbox) and empty($robots_checkbox)))  {
				$this -> index($this -> configloader -> _config['post_message']['auth_robot']);
			} else if ($admin_data_array['flag'] and $admin_data_array['admin_data']['admin_password'] === $password_post) {
				$this -> setAuthorization($admin_data_array['admin_data']);
			} else {
				$this -> index($this -> configloader -> _config['post_message']['auth_error']);
			}
		}
	}

	/**
	 * setAuthorization
	 * 
	 * This function to set auth cookie
	 *
	 * @access private
	 * @param array $admin_data_array
	 */
	private function setAuthorization($admin_data_array) {

		/**
		 * Generate hash
		 */
		$hash = random_string('alnum', 32);
		
		/**
		 * Update hash in DB
		 */
		$this -> auth_model -> updateHash($admin_data_array['admin_id'], $hash);
		
		/**
		 * Set cookie with admin id and admin hash
		 */
		if ($this -> input -> post('valueRemember') == 1) {
			$this -> input -> set_cookie('admin_id', $admin_data_array['admin_id'], $this -> configloader -> _config['cookie']['thirty_days']);
			$this -> input -> set_cookie('admin_login', $admin_data_array['admin_login'], $this -> configloader -> _config['cookie']['thirty_days']);
			$this -> input -> set_cookie('admin_hash', $hash, $this -> configloader -> _config['cookie']['thirty_days']);
		} else {
			$this -> input -> set_cookie('admin_id', $admin_data_array['admin_id'], $this -> configloader -> _config['cookie']['one_day']);
			$this -> input -> set_cookie('admin_login', $admin_data_array['admin_login'], $this -> configloader -> _config['cookie']['one_day']);
			$this -> input -> set_cookie('admin_hash', $hash, $this -> configloader -> _config['cookie']['one_day']);
		}

		/**
		 * Redirect administrator to page layout
		 */
		redirect(base_url() . 'layout/');
	}
}