<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Editaccess.php
 *
 * This is administrator edit access file
 *
 * @category	controllers
 * @package		LP cms
 * @link		https://lpcms.net
 * @copyright	2017
 * @license 	MIT License (https://en.wikipedia.org/wiki/MIT_License)
 * @version 	0.1 Beta
 */

/**
 * Editaccess
 * 
 * This is class for edit access of administrator
 * 
 * @author 		Developers of lpcms.net <dev@lpcms.net>
 * @see 		/editaccess/
 * @version 	0.1 Beta
 */
class Editaccess extends CI_Controller {

	/**
	 * _login_rules
	 * 
	 * @var array
	 */
	private $_login_rules = array(
		'field' => 'form_new_login',
        'name' 	=> 'Login',
        'rules' => 'trim|required|min_length[5]|max_length[16]|alpha|is_unique[administrators.admin_login]'
	);

	/**
	 * _password_rules
	 * 
	 * @var array
	 */
	private $_password_rules = array(
		'field' => 'form_new_password',
        'name' 	=> 'Password',
        'rules' => 'trim|required|min_length[6]|max_length[16]|alpha_numeric'
	);

	/**
	 * _password_again_rules
	 * 
	 * @var array
	 */
	private $_password_again_rules = array(
		'field' => 'form_new_password_again',
        'name' 	=> 'Password AGAIN',
        'rules' => 'trim|required|min_length[6]|max_length[16]|alpha_numeric'
	);

	/**
	 * index
	 * 
	 * This function is Index Page of controller 
	 *
	 * @access public
	 * @param string $error_login_message
	 * @param string $success_login_message
	 * @param string $error_password_message
	 * @param string $success_password_message
	 */
	public function index($error_login_message = NULL, $success_login_message = NULL, $error_password_message = NULL, $success_password_message = NULL) {

		/**
		 * Check authorization
		 */
		$this -> ischecks -> checkAuthorization();

		/**
		 * Set parameters for our template
		 */
		$data_header = array(
			'title'				=> 'Измененить доступы к сайту',
			'admin_name' 		=> get_cookie('admin_login'),
			'active_main' 		=> '',
			'active_content' 	=> '',
			'active_form'	 	=> '',
			'active_template' 	=> '',
			'active_access'	  	=> ' class="active"',
			'active_info'		=> '',
			'breadcrumbs' 		=> 'Изменить логин и пароль',
			// 'pub_admin_css_path'=> $this -> configloader -> _config['paths']['pub_admin_css'],
			// 'file_style'		=> $this -> configloader -> _config['admin_style']['news'],
			'year'				=> date("Y")
		);

		$data_access = array(
			'admin_old_login' 	=> get_cookie('admin_login'),
			'login_value'		=> set_value('form_new_login', ''),
			'admin_old_password'=> set_value('form_old_password', ''),
			'admin_new_password'=> set_value('form_new_password', ''),
			'admin_new_password_again'=> set_value('form_new_password_again', ''),
			'error_login'		=> $error_login_message,
			'success_login'		=> $success_login_message,
			'error_password'	=> $error_password_message,
			'success_password'	=> $success_password_message
		);

		$data_footer = array();

		/**
		 * Set name for our template
		 */
		$template_header = $this -> configloader -> _config['templates_admin']['header'];
		$template_access = $this -> configloader -> _config['templates_admin']['edit_access'];
		$template_footer = $this -> configloader -> _config['templates_admin']['footer'];

		/**
		 * Set header with nocashe
		 */
		$this -> cache -> clear();

		/**
		 * Parse our template
		 */
		$this -> parser -> parse($template_header, $data_header);
		$this -> parser -> parse($template_access, $data_access);
		$this -> parser -> parse($template_footer, $data_footer);
	}

	/**
	 * editLogin
	 * 
	 * This function edit login of administrator 
	 *
	 * @access public
	 */
	public function editLogin() {

		/**
		 * Check authorization
		 */
		$this -> ischecks -> checkAuthorization();

		/**
		 * Form submit value
		 */
		$form_login_submit = $this -> input -> post('form_login_submit');

		/**
		 * If form submit
		 */
		if (isset($form_login_submit) and !empty($form_login_submit)) {
			/**
			 * Login validation
			 */
			$this -> form_validation -> set_rules($this -> _login_rules['field'], $this -> _login_rules['name'], $this -> _login_rules['rules']);

			/**
			 * Set container for error block
			 */
			$this -> form_validation -> set_error_delimiters('', '');

			/**
			 * If form not form valid then show error or set cookies
			 */
			if ($this -> form_validation -> run() == FALSE) {
			
				/**
				 * If form not form valid then show error
				 */
				$this -> index(validation_errors());
			} else {

				/**
				 * Set variables from form
				 */
				$form_old_login = $this -> input -> post('form_old_login_hidden');
				$form_new_login = $this -> input -> post('form_new_login');
				$form_old_login_true = get_cookie('admin_login');

				/**
				 * Write new admin login to DB 
				 */
				if ($this -> admin_model -> writeNewAdminLogin($form_new_login)) {

					/**
					 * Show success error
					 */
					$this -> index(NULL, 'New login wtite to DB. Logout please and login.');
				}
			}
		}
	}

	/**
	 * editPassword
	 * 
	 * This function edit password of administrator 
	 *
	 * @access public
	 */
	public function editPassword() {

		/**
		 * Check authorization
		 */
		$this -> ischecks -> checkAuthorization();

		/**
		 * Form submit value
		 */
		$form_password_submit = $this -> input -> post('form_password_submit');
		$admin_login = get_cookie('admin_login');

		/**
		 * If form submit
		 */
		if (isset($form_password_submit) and !empty($form_password_submit)) {

			/**
			 * Password validation
			 */
			$this -> form_validation -> set_rules($this -> _password_rules['field'], $this -> _password_rules['name'], $this -> _password_rules['rules']);

			/**
			 * Password validation
			 */
			$this -> form_validation -> set_rules($this -> _password_again_rules['field'], $this -> _password_again_rules['name'], $this -> _password_again_rules['rules']);

			/**
			 * Set container for error block
			 */
			$this -> form_validation -> set_error_delimiters('', '');

			/**
			 * If form not form valid then show error or set cookies
			 */
			if ($this -> form_validation -> run() == FALSE) {

				/**
				 * If form not form valid then show error
				 */
				$this -> index(NULL, NULL, validation_errors());
			} else {

				/**
				 * Get a password of administrator
				 */
				$get_admin_password = $this -> admin_model -> getAdminPassword($admin_login);

				/**
				 * Set variables from form
				 */
				$form_old_password = $this -> input -> post('form_old_password');
				$form_new_password = $this -> input -> post('form_new_password');
				$form_new_password_again = $this -> input -> post('form_new_password_again');
				$form_old_password_hash = md5(md5($this -> input -> post('form_old_password')));
				$form_new_password_hash = md5(md5($this -> input -> post('form_new_password_again')));

				/**
				 * If old admin password is good in DB 
				 */
				if ($get_admin_password['admin_password'] == $form_old_password_hash) {

					if ($form_old_password == $form_new_password and $form_old_password == $form_new_password_again) {

						/**
						 * Show success error
						 */
						$this -> index(NULL, NULL, 'Новый пароль и старый пароль Администратора совпадают.', NULL);
					} else {

						/**
						 * If new password and new password again do not match
						 */
						if ($form_new_password == $form_new_password_again) {

							/**
							 * Write new admin login to DB 
							 */
							if ($this -> admin_model -> writeNewAdminPassword($admin_login, $form_new_password_hash)) {

								/**
								 * Show success error
								 */
								$this -> index(NULL, NULL, NULL, 'Новый пароль Администратора успешно сохранён. пожалуйста выйдите и войдите в систему.');

								/**
								 * Clear form
								 */
								unset($this->_field_data);
							}
						} else {
							/**
							 * If form not form valid then show error
							 */
							$this -> index(NULL, NULL, 'Новые пароли Администратора не совпадают.');
						}
					}
				} else {
					/**
					 * If form not form valid then show error
					 */
					$this -> index(NULL, NULL, 'Старый пароль Администратора введён не верно.');
				}
			}
		}
	}
}