<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Install.php
 *
 * This is file of instructions for install platform
 *
 * @category	controllers
 * @package		LP cms
 * @link		https://lpcms.net
 * @copyright	2017
 * @license 	MIT License (https://en.wikipedia.org/wiki/MIT_License)
 * @version 	0.1 Beta
 */

/**
 * Install
 * 
 * This is class create an instructons for install our platform
 * 
 * @author 		Developers of lpcms.net <dev@lpcms.net>
 * @see 		/install/
 * @version 	0.1 Beta
 */
class Install extends CI_Controller {

	/**
	 * index
	 * 
	 * This is Authorization class
	 *
	 * @access public
	 */
	public function index() {

		/**
		 * Get install complete flag
		 */
		$install_complete = $this -> admin_model -> getCompleteInstallPlatformToDB();

		/**
		 * If install platform is complete, then redirect user on main page
		 */
		if ($install_complete['install_flag'] == 1) {
			redirect(base_url());
		}

		/**
		 * Get hosting info
		 */
		$hosting_info = $this -> getHostionInfo();

		/**
		 * Set parameters for our template
		 */
		$data_install = array(
			// 'action_name' => get from language file
			'title'				=> 'Установка LPcms ' . $this -> configloader -> _config['platform']['version'],
			'platform_version'	=> $this -> configloader -> _config['platform']['version'],
			'hosting_info' 		=> $hosting_info,
			'pub_admin_css_path'=> $this -> configloader -> _config['paths']['pub_user_css'],
			'file_style'		=> $this -> configloader -> _config['admin_style']['install'],
			'year'				=> date("Y"),
			// 'version'			=> CI_VERSION,
		);


		/**
		 * Set name for our template
		 */
		$template_install = $this -> configloader -> _config['templates_user']['install'];

		/**
		 * Set header with nocashe
		 */
		$this -> cache -> clear();

		/**
		 * Parse our template
		 */
		$this -> parser -> parse($template_install, $data_install);
	}

	/**
	 * getHostionInfo
	 * 
	 * This function get information about Apache, PHP, MySql and Short Open Tag для PHP 
	 *
	 * @access private
	 * @return array 
	 */
	private function getHostionInfo() {

		/**
		 * Set flag error and ok
		 */
		$ok = '<span class="glyphicon glyphicon-ok text-success pull-right"></span>';
		$error = '<span class="glyphicon glyphicon-remove text-danger pull-right"></span>';

		/**
		 * Check Apache
		 */
		if (strstr($_SERVER['SERVER_SOFTWARE'], 'Apache')) {
		    $apache = $ok;
		} else {
		    $apache = $error;
		}

		/**
		 * Check PHP
		 */
		if (floatval(phpversion()) < 5.2) {
		    $php = $error;
		} else {
		    $php = $ok;
		}

		/**
		 * Check MySQL
		 */
		if (@mysqli_get_server_info($link_db)) {
		    $mysqlversion = substr(@mysqli_get_server_info($link_db), 0, 1);
		    if ($mysqlversion >= 4) {
		        $mysql = $ok;
		    } else {
		        $mysql = $error;
		    }
		} else {
		    $mysql = $ok;
		}

		/**
		 * Check short_open_tag (PHP)
		 */
		if (ini_get("short_open_tag") == 1) {
		    $tag = $ok;
		} else {
		    $tag = $error;
		}

		/**
		 * Return array with our hosting checks
		 */
		return array(
			'apache'		=> $apache,
			'php'			=> $php,
			'mysql'			=> $mysql,
			'short_open_tag'=> $tag
		);
	}

	/**
	 * complete
	 * 
	 * This function complete installation for LPcms
	 *
	 * @access public
	 */
	public function complete() {
		
		/**
		 * Set variable
		 */
		$install_flag = 1;

		/**
		 * Set path for folder
		 */
		$set_path = dirname(__FILE__) . '/../../pub/admin/ckeditor_4.6.0_full/img/';

		/**
		 * Set chmod for folder 
		 */
		$set_chmod_folder = chmod($set_path, 0777);

		/**
		 * Set our complete install in DB
		 */
		$this -> admin_model -> writeCompleteInstallPlatformToDB($install_flag);

		/**
		 * Redirect our admin on layout page
		 */
		redirect(base_url() . 'layout/?complete=1');
	}
}