<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Admin_model.php
 *
 * This is administrator model file
 *
 * @category	models
 * @package		LP cms
 * @link		https://lpcms.net
 * @copyright	2017
 * @license 	MIT License (https://en.wikipedia.org/wiki/MIT_License)
 * @version 	0.1 Beta
 */

/**
 * Admin_model
 * 
 * This is administrator model class
 * 
 * @author 		Developers of lpcms.net <dev@lpcms.net>
 * @see 		$this -> admin_model -> method_name
 * @version 	0.1 Beta
 */
class Admin_model extends CI_Model {

	/**
	 * _DB_table_name_content
	 * 
	 * @var string	This is name of table with content
	 */
	private $_DB_table_name_content;

	/**
	 * _DB_table_name_administrators
	 * 
	 * @var string	This is name of table with data of administrator
	 */
	private $_DB_table_name_administrators;
	
	/**
	 * __construct
	 * 
	 * This function initialize a name of table
	 * 
	 * @access public
	 */
	public function __construct() {
		/**
		 * Set variables with name of table with content
		 */
		$this -> _DB_table_name_content	= $this -> configloader -> _config['table_names']['content'];

		/**
		 * Set variables with name of DB table with data of administrator
		 */
		$this -> _DB_table_name_administrators = $this -> configloader -> _config['table_names']['admins'];
	}
	
	/**
	 * getAdminHTMLContent
	 * 
	 * This function get HTML content of our Landind Page
	 *
	 * @access public
	 * @return array / boolean
	 */
	public function getAdminHTMLContent() {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Select data from Table
		 */
		$this->db->select('html');
		$this -> db -> where(
			array('id' => $id)
		);
		$query = $this -> db -> get($this -> _DB_table_name_content);

		/**
		 * If array not empty, then return data, else return false
		 */
		if ($query -> num_rows() > 0) {
			return $query -> row_array();
		} else {
			return FALSE;
		}
	}

	/**
	 * saveAdminHTMLContent
	 * 
	 * This function save HTML content for our Landind Page
	 *
	 * @access public
	 * @param string $new html
	 * @return boolean $update
	 */
	public function saveAdminHTMLContent($new_html) {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Set array with data
		 */
		$update_data = array(
			'html' => $new_html
		);

		/**
		 * Update data in Table
		 */
		$update = $this -> db -> update($this -> _DB_table_name_content, $update_data, array('id' => $id));
		
		/**
		 * Return sql responce
		 */
		return $update;
	}

	/**
	 * writeFormDataToDB
	 * 
	 * This function write a data from our form to DB
	 *
	 * @access public
	 * @param serialize $serialize_form_data
	 * @return boolean $update_form_data
	 */
	public function writeFormDataToDB($serialize_form_data) {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Set array with data
		 */
		$form_data = array(
			'form' => $serialize_form_data
		);

		/**
		 * Update a field of table with data of form 
		 */
		$update_form_data = $this -> db -> update($this -> _DB_table_name_content, $form_data, array('id' => $id));

		/**
		 * Return request status
		 */
		return $update_form_data;
	}

	/**
	 * getFormDataFromDB
	 * 
	 * This function write a data from form to DB
	 *
	 * @access public
	 * @return array / boolean
	 */
	public function getFormDataFromDB() {
		
		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Select data from DB
		 */
		$this->db->select('form');
		$this -> db -> where(
			array('id' => $id)
		);
		$query = $this -> db -> get($this -> _DB_table_name_content);

		/**
		 * If array not empty, then return data, else return false
		 */
		if ($query -> num_rows() > 0) {
			return $query -> row_array();
		} else {
			return FALSE;
		}
	}

	/**
	 * writeNewAdminLogin
	 * 
	 * This function write a new login of administrator to DB
	 *
	 * @access public
	 * @param string ([3-6, a-z]) $admin_new_login
	 * @return boolean $update_admin_login
	 */
	public function writeNewAdminLogin($admin_new_login) {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Set array with data
		 */
		$admin_data = array(
			'admin_login' => $admin_new_login
		);

		/**
		 * Update a field of table with data of form 
		 */
		$update_admin_login = $this -> db -> update($this -> _DB_table_name_administrators, $admin_data, array('admin_id' => $id));

		/**
		 * Return request status
		 */
		return $update_admin_login;
	}

	/**
	 * getAdminPassword
	 * 
	 * This function get a password of administrator from DB
	 *
	 * @access public
	 * @param string $admin_login
	 * @return array / boolean
	 */
	public function getAdminPassword($admin_login) {

		/**
		 * Select data from DB
		 */
		$this -> db -> select('admin_password');
		$this -> db -> where(
			array('admin_login' => $admin_login)
		);
		$query = $this -> db -> get($this -> _DB_table_name_administrators);

		/**
		 * If array not empty, then return data, else return false
		 */
		if ($query -> num_rows() > 0) {
			return $query -> row_array();
		} else {
			return FALSE;
		}
	}

	/**
	 * writeNewAdminPassword
	 * 
	 * This function write a new admin password to DB
	 *
	 * @access public
 	 * @param string $admin_login
	 * @param string $admin_new_password
	 * @return boolean $update_admin_password
	 */
	public function writeNewAdminPassword($admin_login, $admin_new_password) {

		/**
		 * Set array with data
		 */
		$admin_data = array(
			'admin_password' => $admin_new_password
		);

		/**
		 * Update a field of table with data of form 
		 */
		$update_admin_password = $this -> db -> update($this -> _DB_table_name_administrators, $admin_data, array('admin_login' => $admin_login));

		/**
		 * Return request status
		 */
		return $update_admin_password;
	}

	/**
	 * saveTemplateNameInDB
	 * 
	 * This function save a name of template in DB
	 *
	 * @access public
	 * @param string $template_name
	 * @return array / boolean
	 */
	public function saveTemplateNameInDB($template_name) {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Set array with data
		 */
		$admin_data = array(
			'template' => $template_name
		);

		/**
		 * Update a field of table with data of tempalte name
		 */
		$update_template_name = $this -> db -> update($this -> _DB_table_name_content, $admin_data, array('id' => $id));

		/**
		 * Return request status
		 */
		return $update_template_name;
	}

	/**
	 * getActiveTemplateNameInDB
	 * 
	 * This function get an active template from DB
	 *
	 * @access public
	 * @return array / boolean
	 */
	public function getActiveTemplateNameInDB() {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Select data from DB
		 */
		$this->db->select('template');
		$this -> db -> where(
			array('id' => $id)
		);
		$query = $this -> db -> get($this -> _DB_table_name_content);

		/**
		 * If array not empty, then return data, else return false
		 */
		if ($query -> num_rows() > 0) {
			return $query -> row_array();
		} else {
			return FALSE;
		}
	}

	/**
	 * getMYSQLversion
	 * 
	 * This function get of MYSQL current version
	 *
	 * @access public
	 * @return array / boolean
	 */
	public function getMYSQLversion() {
		
		/**
		 * Select a version of MYSQL
		 */
		$query = $this -> db -> query("SELECT VERSION() as mysql_version");

		/**
		 * If array not empty, then return data, else return false
		 */
		if ($query -> num_rows() > 0) {
			return $query -> row_array();
		} else {
			return FALSE;
		}
	}

	/**
	 * writeCompleteInstallPlatformToDB
	 * 
	 * This function write a data for a complete install to DB
	 *
	 * @access public
	 * @param integer $install_flag
	 * @return boolean $update_install_data
	 */
	public function writeCompleteInstallPlatformToDB($install_flag) {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Set array with data
		 */
		$install_data = array(
			'install_flag' => $install_flag
		);

		/**
		 * Update a field of table with data of install
		 */
		$update_install_data = $this -> db -> update($this -> _DB_table_name_content, $install_data, array('id' => $id));

		/**
		 * Return request status
		 */
		return $update_install_data;
	}

	/**
	 * getCompleteInstallPlatformToDB
	 * 
	 * This function a get of MYSQL install complete
	 *
	 * @access public
	 * @return array / boolean
	 */
	public function getCompleteInstallPlatformToDB() {

		/**
		 * Set id for query
		 */
		$id = 1;

		/**
		 * Select data from DB
		 */
		$this->db->select('install_flag');
		$this -> db -> where(
			array('id' => $id)
		);
		$query = $this -> db -> get($this -> _DB_table_name_content);

		/**
		 * If array not empty, then return data, else return false
		 */
		if ($query -> num_rows() > 0) {
			return $query -> row_array();
		} else {
			return FALSE;
		}
	}
}