<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Auth_model.php
 *
 * This is authorization model file
 *
 * @category	models
 * @package		LP cms
 * @link		https://lpcms.net
 * @copyright	2017
 * @license 	MIT License (https://en.wikipedia.org/wiki/MIT_License)
 * @version 	0.1 Beta
 */

/**
 * Auth_model
 * 
 * This is authorization model class
 * 
 * @author 		Developers of lpcms.net <dev@lpcms.net>
 * @see 		$this -> auth_model -> method_name
 * @version 	0.1 Beta
 */
class Auth_model extends CI_Model {
	
	/**
	 * _DB_table_name_administrators
	 * 
	 * @var string	This is name of table with data of administrator
	 */
	private $_DB_table_name_administrators;
	
	/**
	 * __construct
	 * 
	 * This function initialize a name of table 
	 * 
	 * @access public
	 */
	public function __construct() {
		/**
		 * Set variables with name of DB table with data of administrator
		 */
		$this -> _DB_table_name_administrators = $this -> configloader -> _config['table_names']['admins'];
	}
	
	/**
	 * getAdminIdAndHash
	 * 
	 * This function get administrator's id and hash
	 *
	 * @access public
	 * @param string $admin_id
	 * @param string $admin_hash
	 * @return array / boolean
	 */
	public function getAdminIdAndHash($admin_id, $admin_hash) {
		
		/**
		 * Select data from SB
		 */
		$this -> db -> select('admin_id, admin_hash');
		$this -> db -> where(
			array(
				'admin_id' 	=> $this -> db -> escape_str($admin_id),
				'admin_hash'=> $this -> db -> escape_str($admin_hash)
			)
		);
		$query = $this -> db -> get($this -> _DB_table_name_administrators);

		/**
		 * If array not empty, then return data, else return false
		 */
		if ($query -> num_rows() > 0) {
			return $query -> row_array();
		} else {
			return FALSE;
		}
	}
	
	/**
	 * getAdminData
	 * 
	 * This function to get a data of administrator
	 *
	 * @access public
	 * @param string $admin_login
	 * @return array / boolean
	 */
	public function getAdminData($admin_login) {
		
		/**
		 * Select data from SB
		 */
		$this -> db -> select('admin_id, admin_login, admin_password, admin_permission');
		$this -> db -> where('admin_login', $this -> db -> escape_str($admin_login));
		
		$query = $this -> db -> get($this -> _DB_table_name_administrators);

		if ($query -> num_rows() > 0) {
			
			$data['flag'] = TRUE;
			$data['admin_data'] = $query -> row_array();
			
			return $data;
		} else {
			return FALSE;
		}
	}
	
	/**
	 * updateHash
	 *
	 * This controller update hash of administrator
	 *
	 * @access public
	 * @param string $admin_id
	 * @param string $hash
	 */
	public function updateHash($admin_id, $hash) {
		$this -> db -> where('admin_id', $this->db->escape_str($admin_id));
		$this -> db -> update($this -> _DB_table_name_administrators, array('admin_hash' => $hash));
	}
}